/* Copyright 2008-2017 Research Foundation State University of New York   */

/* This file is part of QUB Online.                                       */

/* QUB Online is free software; you can redistribute it and/or modify    */
/* it under the terms of the GNU General Public License as published by   */
/* the Free Software Foundation, either version 3 of the License, or      */
/* (at your option) any later version.                                    */

/* QUB Online is distributed in the hope that it will be useful,         */
/* but WITHOUT ANY WARRANTY; without even the implied warranty of         */
/* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          */
/* GNU General Public License for more details.                           */

/* You should have received a copy of the GNU General Public License,     */
/* named LICENSE.txt, in the QUB Online program directory.  If not, see  */
/* <http://www.gnu.org/licenses/>.                                        */

#ifndef QUB_RASTER_SAMPLES_H
#define QUB_RASTER_SAMPLES_H

#include "qubfast.h"

#ifdef __cplusplus
extern "C" {
#endif

QUBFAST_API int qub_raster_samples(int w, int Nsample, float *samples, double samples_per_pixel, double y_res,
                                   float *lows, float *highs, float *gauss_lows, float *gauss_highs);
/*
Downsamples data into min/max and +/- one std. each pixel.
Fills in lows, highs, gauss_lows, gauss_highs; returns number of output pixels (at most w).

    @param w: display pixel width
    @param Nsample: length of samples
    @param samples: raw data
    @param samples_per_pixel: 
    @param y_res: min difference between highs[i] and lows[i]
    @param lows: output array for at most w minimum values
    @param highs: output array for at most w maximum values
    @param gauss_lows: output array for at most w mean+std values
    @param gauss_highs: output array for at most w mean-std values
*/


#ifdef __cplusplus
}
#endif

#endif
